SipAccount class

SIP Account Manager - Handles multiple SIP registrations

Constructors

SipAccount({required String accountId, required String domain, required String username, String? realm, String? callerId, String? displayName})

Properties

accountId String
final
callerId String?
final
displayName String?
final
domain String
final
hashCode int
The hash code for this object.
no setterinherited
isRegistered bool
no setter
realm String?
final
registrationState ↔ RegistrationState?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transportState ↔ TransportState?
getter/setter pair
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited