SipService class
Constructors
- SipService()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
callStateChanged(
Call call, CallState state) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onNewMessage(
SIPMessageRequest msg) → void -
onNewNotify(
Notify ntf) → void -
onNewReinvite(
ReInvite event) → void -
registrationStateChanged(
RegistrationState state) → void -
toString(
) → String -
A string representation of this object.
inherited
-
transportStateChanged(
TransportState state) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- callState → CallState?
-
Get call state
no setter
- isInCall → bool
-
Check if in call
no setter
- isRegistered → bool
-
Check if registered
no setter
- isTransportConnected → bool
-
Check if transport is connected
no setter
- onCallStateChanged ↔ dynamic Function(CallState)?
-
getter/setter pair
- onRegistrationStateChanged ↔ dynamic Function(RegistrationState)?
-
getter/setter pair
- onTransportStateChanged ↔ dynamic Function(TransportState)?
-
getter/setter pair
- registrationState → RegistrationState?
-
Get registration state
no setter
- transportState → TransportState?
-
Get transport state
no setter
Static Methods
-
answerCall(
) → Future< void> - Answer incoming call
-
dispose(
) → Future< void> - Dispose SIP service
-
hangup(
) → Future< void> - Hangup current call
-
initialize(
) → Future< void> - Initialize SIP service
-
makeCall(
String targetUri) → Future< void> - Make SIP call
-
register(
{required String username, required String password, String? domain, String? realm, String? displayName, String? callerId, String? sendAs, String? sipServer, int port = 5060, bool useWebSocket = false, String? wsUrl}) → Future< bool> - Register SIP extension
-
unregister(
) → Future< void> - Unregister SIP extension