MultiVoipPlugin class
Multi-Account VoIP Plugin - Supports multiple SIP registrations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
onAccountCallStateChanged
↔ dynamic Function(String accountId, String status, Map<
String, dynamic> ? data)? -
Callback for account call state changes
getter/setter pair
- onAccountRegistrationChanged ↔ dynamic Function(String accountId, bool isRegistered, String status)?
-
Callback for account registration state changes
getter/setter pair
-
registeredAccounts
→ List<
SipAccount> -
Get all registered accounts
no setter
Static Methods
-
answerCall(
String accountId) → Future< void> - Answer incoming call
-
dispose(
) → Future< void> - Dispose all accounts
-
getAccount(
String accountId) → SipAccount? - Get account by ID
-
hangup(
String accountId) → Future< void> - Hangup call for a specific account
-
initialize(
) → Future< void> - Initialize multi-account plugin
-
isAccountInCall(
String accountId) → bool - Check if account is in call
-
isAccountRegistered(
String accountId) → bool - Check if account is registered
-
makeCall(
{required String accountId, required String target}) → Future< void> - Make a call from a specific account
-
registerAccount(
{required String domain, required String username, required String password, String? realm, String? callerId, String? displayName, int port = 5060, bool useWebSocket = false, String? accountId}) → Future< String> - Register a new SIP account Returns the account ID
-
unregisterAccount(
String accountId) → Future< void> - Unregister a specific account