SipConfig class

SIP Configuration Model

Constructors

SipConfig({required String domain, required String username, required String password, String? realm, String? callerId, String? displayName, int port = 5060, bool useWebSocket = false})
const

Properties

callerId String?
final
displayName String?
final
domain String
final
hashCode int
The hash code for this object.
no setterinherited
password String
final
port int
final
realm String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
final
useWebSocket bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited