VoipService class

Constructors

VoipService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

onCallStatusChanged ↔ dynamic Function(String status, Map<String, dynamic>? data)?
getter/setter pair
uuid → Uuid
final

Static Methods

dispose() Future<void>
Dispose VoIP service
endAllCalls() Future<void>
End all calls
endCall(String callId) Future<void>
End current call
getActiveCalls() Future<List<CallKitParams>?>
Get active calls
initialize() Future<void>
Initialize VoIP service
showIncomingCall({required String callerName, required String callerId, String? avatar, String? accountId}) Future<String>
Show incoming call Returns the CallKit call ID
startOutgoingCall({required String callerName, required String callerId, String? avatar}) Future<void>
Start an outgoing call